@@ -33,6 +33,10 @@ class BaseStorageBackend(metaclass=abc.ABCMeta):
         """
         raise NotImplementedError("Subclasses must override this method.")
 
+    def download(self, path, dst):
+        """Downloads file from `path` to `dst` on the local filesystem."""
+        raise NotImplementedError("Subclasses must override this method.")
+
     def push(self, src, path):
         """Copies local absolute path `src` to remote `path`."""
         raise NotImplementedError("Subclasses must override this method.")
@@ -59,6 +63,15 @@ class BaseStorageBackend(metaclass=abc.ABCMeta):
         """
         raise NotImplementedError("Subclasses must override this method.")
 
+    def pull(self, path, dst=None):
+        """Pulls a file from the given `path` in the storage backend to local
+        filepath `dst`. If `dst` is ``None``, then a temporary filepath is
+        generated.
+        """
+        if dst is None:
+            _, dst = tempfile.mkstemp()
+        return self.download(path, dst)
+
     def storage_path(self, *components):
         """Returns the absolute path in the storage of `path`."""
         return os.path.join(self.base_path or '', *components)
