@@ -25,6 +25,12 @@ class StorageBackend(RemoteStorageBackendMixin, BaseStorageBackend):
             blob = self.bucket.blob(dst)
             blob.upload_from_filename(handler.fd.name)
 
+    def download(self, path, dst):
+        """Downloads file from `path` to `dst` on the local filesystem."""
+        blob = self.bucket.blob(self.storage_path(path))
+        blob.download_to_filename(dst)
+        return dst
+
     def exists(self, path):
         """Test whether a path exists.  Returns False for broken symbolic links
         if the storage backend supports them.
@@ -42,8 +48,7 @@ class StorageBackend(RemoteStorageBackendMixin, BaseStorageBackend):
             raise NotImplementedError("Partial reads are not implemented.")
 
         # TODO: This is not going to play well with seeking and friends (pylint: disable=W0511).
-        blob = self.bucket.blob(self.storage_path(handler.path))
-        blob.download_to_filename(handler.fd.name)
+        self.download(handler.path, handler.fd.name)
         return handler.fd.read(size)
 
     def push(self, src, path):
