@@ -15,6 +15,11 @@ class LocalDiskBackend(BaseStorageBackend):
         """
         handler.fd.close()
 
+    def download(self, path, dst):
+        """This method exists only for API compatibility."""
+        shutil.copy2(self.storage_path(path), dst)
+        return dst
+
     def exists(self, path):
         """Test whether a path exists.  Returns False for broken symbolic links
         if the storage backend supports them.
@@ -23,7 +28,10 @@ class LocalDiskBackend(BaseStorageBackend):
 
     def get_local_fd(self, handler):
         """Opens a local file descriptor."""
-        return open(self.storage_path(handler.path), handler.mode)
+        local_path = self.storage_path(handler.path)
+        if not os.path.exists(os.path.dirname(local_path)):
+            os.makedirs(os.path.dirname(local_path))
+        return open(local_path, handler.mode)
 
     def read(self, handler, size=-1):
         """Read at most n characters from handler.
