@@ -27,6 +27,7 @@ class LocalDiskBackendTestCase(unittest.TestCase):
         src = 'foo'
         with self.backend.open(src, 'w') as f:
             f.write("Hello world!")
+        self.assertTrue(self.backend.exists(src))
         with self.backend.open(src) as f:
             pass
         self.assertTrue(f.is_closed())
@@ -77,6 +78,17 @@ class LocalDiskBackendTestCase(unittest.TestCase):
         with self.assertRaises(ValueError):
             fd.read()
 
+    def test_pull_without_dst(self):
+        path = '%s/%s' % (bytes.hex(os.urandom(8)), bytes.hex(os.urandom(8)))
+        with self.backend.open(path, 'w') as f:
+            f.write("Hello world!")
+
+        self.assertTrue(self.backend.exists(path))
+        tmp = self.backend.pull(path)
+
+        with open(tmp) as f:
+            self.assertEqual("Hello world!", f.read())
+
     def test_push(self):
         with tempfile.NamedTemporaryFile() as f:
             f.write(b"Hello world!")
